@@ -78,8 +78,8 @@
 #endif
 
 /* vtkSMPTools back-end */
-#define VTK_SMP_Sequential
-#define VTK_SMP_BACKEND "Sequential"
+#define VTK_SMP_TBB
+#define VTK_SMP_BACKEND "TBB"
 
 /* Compiler features.  */
 /* #undef VTK_HAVE_GETSOCKNAME_WITH_SOCKLEN_T */
