@@ -33,9 +33,8 @@
 #endif
 
 /* AutoInit dependencies.  */
-#include "vtkFiltersParallelModule.h"
+#include "vtkIOGeometryModule.h"
 #include "vtkIOImageModule.h"
-#include "vtkIOXMLModule.h"
 
 /* AutoInit implementations.  */
 #if defined(vtkIOParallel_INCLUDE)
